/*   This is part of um-ViewOS
 *   The user-mode implementation of OSVIEW -- A Process with a View
 *
 *   
 *
 *   Copyright 2005 Renzo Davoli University of Bologna - Italy
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License, version 2, as
 *   published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *   $Id: umfusestd.h 787 2009-09-11 14:46:23Z rd235 $
 *
 */
#ifndef __UM_FUSESTD_H
#define __UM_FUSESTD_H

/** Enable debuging output */
#define FUSE_DEBUG       (1 << 29)
/** Enable human mode */
#define FUSE_HUMAN       (1 << 28)
/** Enable merge mode */
#define FUSE_MERGE       (1 << 27)
/** Enable hard remove */
#define FUSE_HARDREMOVE  (1 << 26)

extern struct fuse_operations defaultservice;

#endif
